@@ -2,7 +2,7 @@
  * libvlc_media_player.h:  libvlc_media_player external API
  *****************************************************************************
  * Copyright (C) 1998-2010 VLC authors and VideoLAN
- * $Id: cc575218a9341d3f8371cff1c2e0e3440edca9f2 $
+ * $Id: c36381f813092895244d1615ab8ba1f8b632b520 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Jean-Paul Saman <jpsaman@videolan.org>
@@ -1025,10 +1025,10 @@ LIBVLC_API libvlc_track_description_t *
  * Set new video subtitle.
  *
  * \param p_mi the media player
- * \param i_spu new video subtitle to select
+ * \param i_spu video subtitle track to select (i_id from track description)
  * \return 0 on success, -1 if out of range
  */
-LIBVLC_API int libvlc_video_set_spu( libvlc_media_player_t *p_mi, unsigned i_spu );
+LIBVLC_API int libvlc_video_set_spu( libvlc_media_player_t *p_mi, int i_spu );
 
 /**
  * Set new video subtitle file.
@@ -1143,7 +1143,7 @@ LIBVLC_API libvlc_track_description_t *
  * Get current video track.
  *
  * \param p_mi media player
- * \return the video track (int) or -1 if none
+ * \return the video track ID (int) or -1 if no active input
  */
 LIBVLC_API int libvlc_video_get_track( libvlc_media_player_t *p_mi );
 
@@ -1151,7 +1151,7 @@ LIBVLC_API int libvlc_video_get_track( libvlc_media_player_t *p_mi );
  * Set video track.
  *
  * \param p_mi media player
- * \param i_track the track (int)
+ * \param i_track the track ID (i_id field from track description)
  * \return 0 on success, -1 if out of range
  */
 LIBVLC_API
@@ -1521,7 +1521,7 @@ LIBVLC_API libvlc_track_description_t *
  * Get current audio track.
  *
  * \param p_mi media player
- * \return the audio track (int), or -1 if none.
+ * \return the audio track ID or -1 if no active input.
  */
 LIBVLC_API int libvlc_audio_get_track( libvlc_media_player_t *p_mi );
 
@@ -1529,7 +1529,7 @@ LIBVLC_API int libvlc_audio_get_track( libvlc_media_player_t *p_mi );
  * Set current audio track.
  *
  * \param p_mi media player
- * \param i_track the track (int)
+ * \param i_track the track ID (i_id field from track description)
  * \return 0 on success, -1 on error
  */
 LIBVLC_API int libvlc_audio_set_track( libvlc_media_player_t *p_mi, int i_track );
