@@ -2,7 +2,7 @@
  * v4l2.c : Video4Linux2 input module for vlc
  *****************************************************************************
  * Copyright (C) 2002-2009 the VideoLAN team
- * $Id: 6337386f724d76da2cabad79d594b21e4ebb38fa $
+ * $Id: 5b9e5644e2209090403413a6146be3a657b90b67 $
  *
  * Authors: Benjamin Pracht <bigben at videolan dot org>
  *          Richard Hosking <richard at hovis dot net>
@@ -1265,7 +1265,12 @@ static int InitVideo( vlc_object_t *p_obj, int i_fd, demux_sys_t *p_sys,
     width = fmt.fmt.pix.width;
     height = fmt.fmt.pix.height;
 
-    if( v4l2_ioctl( i_fd, VIDIOC_G_FMT, &fmt ) < 0 ) {;}
+    if( v4l2_ioctl( i_fd, VIDIOC_G_FMT, &fmt ) < 0 )
+    {
+        msg_Err( p_obj, "Could not get selected video format: %m" );
+        goto error;
+    }
+
     /* Print extra info */
     msg_Dbg( p_obj, "Driver requires at most %d bytes to store a complete image", fmt.fmt.pix.sizeimage );
     /* Check interlacing */
@@ -1325,6 +1330,11 @@ static int InitVideo( vlc_object_t *p_obj, int i_fd, demux_sys_t *p_sys,
             break;
         }
     }
+    if( !p_sys->i_fourcc )
+    {
+        msg_Err( p_obj, "Could not match pixel format" );
+        goto error;
+    }
 
     /* Buggy driver paranoia */
     i_min = fmt.fmt.pix.width * 2;
