@@ -76,12 +76,16 @@ vlc_module_begin ()
 
     set_callbacks( Open, Close )
     add_shortcut( "spatializer" )
-    add_float( "spatializer-roomsize", 1.05, ROOMSIZE_TEXT,
-               ROOMSIZE_LONGTEXT, true )
-    add_float( "spatializer-width", 10., WIDTH_TEXT,WIDTH_LONGTEXT, true )
-    add_float( "spatializer-wet", 3., WET_TEXT,WET_LONGTEXT, true )
-    add_float( "spatializer-dry", 2., DRY_TEXT,DRY_LONGTEXT, true )
-    add_float_with_range( "spatializer-damp", 1., 0., 4., DAMP_TEXT,DAMP_LONGTEXT, true )
+    add_float_with_range( "spatializer-roomsize", 0.85, 0., 1.1,
+                            ROOMSIZE_TEXT, ROOMSIZE_LONGTEXT, false )
+    add_float_with_range( "spatializer-width", 1,     0.,  1.,
+                            WIDTH_TEXT,WIDTH_LONGTEXT, false )
+    add_float_with_range( "spatializer-wet",   0.4,   0.,  1.,
+                            WET_TEXT,WET_LONGTEXT, false )
+    add_float_with_range( "spatializer-dry",   0.5,   0.,  1.,
+                            DRY_TEXT,DRY_LONGTEXT, false )
+    add_float_with_range( "spatializer-damp",  0.5,   0.,  1.,
+                            DAMP_TEXT,DAMP_LONGTEXT, false )
 vlc_module_end ()
 
 /*****************************************************************************
