@@ -2,7 +2,7 @@
  * extended_panels.cpp : Extended controls panels
  ****************************************************************************
  * Copyright (C) 2006-2008 the VideoLAN team
- * $Id: d439a138457db9e3ff233fc40b00f657f8ea4231 $
+ * $Id: 04b1f909915f81913646f302687b97021842dedd $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Antoine Cellerier <dionoea .t videolan d@t org>
@@ -450,7 +450,7 @@ void ExtVideo::initComboBoxItems( QObject *widget )
                                    p_item->pi_list[i_index] );
             else if( i_type == CONFIG_ITEM_STRING )
                 combobox->addItem( qtr( p_item->ppsz_list_text[i_index] ),
-                                   p_item->ppsz_list[i_index] );
+                                   qfu(p_item->ppsz_list[i_index]) );
         }
     }
     else
@@ -1226,8 +1226,6 @@ Compressor::Compressor( intf_thread_t *_p_intf, QWidget *_parent )
 
         oldControlVars[i] = comp_controls[i].f_value;
 
-        CONNECT( compCtrl[i], valueChanged( int ), this, setInitValues() );
-
         ctrl_texts[i] = new QLabel( qtr( comp_controls[i].psz_descs ) + "\n" );
         ctrl_texts[i]->setFont( smallFont );
         ctrl_texts[i]->setAlignment( Qt::AlignHCenter );
@@ -1241,6 +1239,9 @@ Compressor::Compressor( intf_thread_t *_p_intf, QWidget *_parent )
         layout->addWidget( ctrl_texts[i],   3, i, Qt::AlignHCenter );
     }
 
+    for( int i = 0; i < NUM_CP_CTRL; i++ )
+        CONNECT( compCtrl[i], valueChanged( int ), this, setInitValues() );
+
     BUTTONACT( enableCheck, enable() );
 
     /* Write down initial values */
@@ -1370,8 +1371,6 @@ Spatializer::Spatializer( intf_thread_t *_p_intf, QWidget *_parent )
         spatCtrl[i]->setValue( (int)var_InheritFloat( p_intf, spat_controls[i].psz_name ) * 10. );
         oldControlVars[i] = spatCtrl[i]->value();
 
-        CONNECT( spatCtrl[i], valueChanged( int ), this, setInitValues() );
-
         ctrl_texts[i] = new QLabel( qtr( spat_controls[i].psz_desc ) + "\n" );
         ctrl_texts[i]->setFont( smallFont );
 
@@ -1385,6 +1384,9 @@ Spatializer::Spatializer( intf_thread_t *_p_intf, QWidget *_parent )
     }
     spatCtrl[0]->setRange( 0, 11 );
 
+    for( int i = 0; i < NUM_SP_CTRL; i++ )
+        CONNECT( spatCtrl[i], valueChanged( int ), this, setInitValues() );
+
     BUTTONACT( enableCheck, enable() );
 
     /* Write down initial values */
