@@ -41,6 +41,7 @@
 #include <QPainter>
 #include <QPalette>
 #include <QScrollBar>
+#include <assert.h>
 
 #include <vlc_playlist.h>
 #include <vlc_services_discovery.h>
@@ -445,6 +446,8 @@ void PLSelector::plItemAdded( int item, int parent )
 
 void PLSelector::plItemRemoved( int id )
 {
+    if( !podcastsParent ) return;
+
     int c = podcastsParent->childCount();
     for( int i = 0; i < c; i++ )
     {
@@ -462,6 +465,8 @@ void PLSelector::plItemRemoved( int id )
 
 void PLSelector::inputItemUpdate( input_item_t *arg )
 {
+    if( !podcastsParent ) return;
+
     int c = podcastsParent->childCount();
     for( int i = 0; i < c; i++ )
     {
@@ -480,6 +485,8 @@ void PLSelector::inputItemUpdate( input_item_t *arg )
 
 void PLSelector::podcastAdd( PLSelItem * )
 {
+    assert( podcastsParent );
+
     bool ok;
     QString url = QInputDialog::getText( this, qtr( "Subscribe" ),
                                          qtr( "Enter URL of the podcast to subscribe to:" ),
