@@ -2,7 +2,7 @@
  * input_manager.cpp : Manage an input and interact with its GUI elements
  ****************************************************************************
  * Copyright (C) 2006-2008 the VideoLAN team
- * $Id: 9f43bd39ddb09c62173cd62137ea9813c20abf2e $
+ * $Id: 0c379adccc3c7b0951ece88c891ad7cf944a3940 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Ilkka Ollakka  <ileoo@videolan.org>
@@ -207,6 +207,7 @@ void InputManager::customEvent( QEvent *event )
             UpdateStatus();
             // UpdateName();
             UpdateArt();
+            UpdateMeta();
             /* Update duration of file */
         }
         break;
@@ -987,11 +988,6 @@ MainInputManager::~MainInputManager()
     var_DelCallback( THEPL, "repeat", RepeatChanged, this );
     var_DelCallback( THEPL, "loop", LoopChanged, this );
 
-    /* Save some interface state in configuration, at module quit */
-    config_PutInt( p_intf, "random", var_GetBool( THEPL, "random" ) );
-    config_PutInt( p_intf, "loop", var_GetBool( THEPL, "loop" ) );
-    config_PutInt( p_intf, "repeat", var_GetBool( THEPL, "repeat" ) );
-
     if( var_InheritBool( p_intf, "qt-autosave-volume" ) )
         config_PutInt( p_intf, "volume", aout_VolumeGet( THEPL ) );
 }
@@ -1144,7 +1140,7 @@ void MainInputManager::pause()
 
 void MainInputManager::toggleRandom()
 {
-    var_ToggleBool( THEPL, "random" );
+    config_PutInt( p_intf, "random", var_ToggleBool( THEPL, "random" ) );
 }
 
 void MainInputManager::notifyRepeatLoop()
@@ -1158,15 +1154,29 @@ void MainInputManager::notifyRepeatLoop()
 void MainInputManager::loopRepeatLoopStatus()
 {
     /* Toggle Normal -> Loop -> Repeat -> Normal ... */
-    if( var_GetBool( THEPL, "repeat" ) )
-        var_SetBool( THEPL, "repeat", false );
-    else if( var_GetBool( THEPL, "loop" ) )
+    bool loop = var_GetBool( THEPL, "loop" );
+    bool repeat = var_GetBool( THEPL, "repeat" );
+
+    if( repeat )
     {
-        var_SetBool( THEPL, "loop", false );
-        var_SetBool( THEPL, "repeat", true );
+        loop = false;
+        repeat = false;
+    }
+    else if( loop )
+    {
+        loop = false;
+        repeat = true;
     }
     else
-        var_SetBool( THEPL, "loop", true );
+    {
+        loop = true;
+        //repeat = false;
+    }
+
+    var_SetBool( THEPL, "loop", loop );
+    var_SetBool( THEPL, "repeat", repeat );
+    config_PutInt( p_intf, "loop", loop );
+    config_PutInt( p_intf, "repeat", repeat );
 }
 
 void MainInputManager::activatePlayQuit( bool b_exit )
