@@ -24,13 +24,20 @@
 
 module("httprequests",package.seeall)
 
+local common = require ("common")
 local dkjson = require ("dkjson")
 
 
 
 --Round the number to the specified precision
 function round(what, precision)
-  if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision) else return "" end
+  if type(what) == "string" then
+    what = common.us_tonumber(what)
+  end
+  if type(what) == "number" then
+    return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision)
+  end
+  return nil
 end
 
 --split text where it matches the delimiter
@@ -58,10 +65,6 @@ function strsplit(text, delimiter)
     return list
 end
 
-function round(what, precision)
-if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision) else return "" end
-end
-
 --main function to process commands sent with the request
 
 processcommands = function ()
@@ -71,7 +74,7 @@ processcommands = function ()
     local id = tonumber(_GET['id'] or -1)
     local val = _GET['val']
     local options = _GET['option']
-    local band = _GET['band']
+    local band = tonumber(_GET['band'])
     if type(options) ~= "table" then -- Deal with the 0 or 1 option case
       options = { options }
     end
@@ -155,14 +158,17 @@ processcommands = function ()
       common.hotkey("key-"..val)
     elseif command == "audiodelay" then
       if vlc.object.input() and val then
+       val = common.us_tonumber(val)
        vlc.var.set(vlc.object.input(),"audio-delay",val)
       end
     elseif command == "rate" then
-      if vlc.object.input() and tonumber(val) >= 0 then
+      val = common.us_tonumber(val)
+      if vlc.object.input() and val >= 0 then
        vlc.var.set(vlc.object.input(),"rate",val)
       end
     elseif command == "subdelay" then
       if vlc.object.input() then
+       val = common.us_tonumber(val)
        vlc.var.set(vlc.object.input(),"spu-delay",val)
       end
     elseif command == "aspectratio" then
@@ -170,8 +176,10 @@ processcommands = function ()
        vlc.var.set(vlc.object.vout(),"aspect-ratio",val)
       end
     elseif command == "preamp" then
+      val = common.us_tonumber(val)
       vlc.equalizer.preampset(val)
     elseif command == "equalizer" then
+      val = common.us_tonumber(val)
       vlc.equalizer.equalizerset(band,val)
     elseif command == "enableeq" then
       if val == '0' then vlc.equalizer.enable(false) else vlc.equalizer.enable(true) end
@@ -201,6 +209,8 @@ end
 function xmlString(s)
   if (type(s)=="string") then
       return vlc.strings.convert_xml_special_chars(s)
+  elseif (type(s)=="number") then
+      return common.us_tostring(s)
   else
       return tostring(s)
   end
@@ -433,7 +443,7 @@ local aout = vlc.object.aout()
     local s ={}
 
     --update api version when new data/commands added
-    s.apiversion=2
+    s.apiversion=3
     s.version=vlc.misc.version()
     s.volume=vlc.volume.get()
 
